@@ -401,14 +401,13 @@ class Channel(callbacks.Plugin):
                 self.log.warning('%s tried to ban %q, but both have %s',
                                  msg.prefix, bannedHostmask, capability)
                 irc.error(format(_('%s has %s too, you can\'t ban '
-                                 'him/her/it.'), bannedNick, capability))
+                                 'them.'), bannedNick, capability))
             else:
                 doBan()
         else:
             self.log.warning('%q attempted kban without %s',
                              msg.prefix, capability)
             irc.errorNoCapability(capability)
-            exact,nick,user,host
 
     @internationalizeDocstring
     def unban(self, irc, msg, args, channel, hostmask):
@@ -555,6 +554,13 @@ class Channel(callbacks.Plugin):
         list = wrap(list)
 
     class ban(callbacks.Commands):
+        def hostmask(self, irc, msg, args, channel, banmask):
+            """[<channel>] <banmask>
+
+            Bans the <banmask> from the <channel>."""
+            irc.queueMsg(ircmsgs.ban(channel, banmask))
+        hostmask = wrap(hostmask, ['op', ('haveHalfop+', _('ban someone')), 'text'])
+
         @internationalizeDocstring
         def add(self, irc, msg, args, channel, banmask, expires):
             """[<channel>] <nick|hostmask> [<expires>]
