@@ -169,7 +169,7 @@ class GithubRepository(GitRepository):
                 import lib2to3
             except ImportError:
                 return _('Plugin is probably not compatible with your '
-                        'Python version (3.x) but could not be converted '
+                        'Python version (3.x) and could not be converted '
                         'because 2to3 is not installed.')
             import subprocess
             fixers = []
@@ -273,6 +273,10 @@ repositories = {
                                                    'Supybot-plugins'
                                                    ),
                'nyuszika7h':       GithubRepository(
+                                                   'nyuszika7h',
+                                                   'limnoria-plugins'
+                                                   ),
+               'nyuszika7h-old':   GithubRepository(
                                                    'nyuszika7h',
                                                    'Supybot-plugins'
                                                    ),
@@ -297,6 +301,10 @@ repositories = {
                                                    'GLolol',
                                                    'SupyPlugins',
                                                    ),
+               'Iota':             GithubRepository(
+                                                   'IotaSpencer',
+                                                   'supyplugins',
+                                                   ),
                }
 
 class PluginDownloader(callbacks.Plugin):
