@@ -315,6 +315,12 @@ def registerNetwork(name, password='', ssl=False, sasl_username='',
     registerGlobalValue(network, 'nick', ValidNickOrEmpty('', _("""Determines
         what nick the bot will use on this network. If empty, defaults to
         supybot.nick.""")))
+    registerGlobalValue(network, 'ident', ValidNickOrEmpty('', _("""Determines
+        the bot's ident string, if the server doesn't provide one by default.
+        If empty, defaults to supybot.ident.""")))
+    registerGlobalValue(network, 'user', registry.String('', _("""Determines
+        the username the bot sends to the server. If empty, defaults to
+        supybot.user""")))
     registerGlobalValue(network, 'umodes',
         registry.String('', _("""Determines what user modes the bot will request
         from the server when it first connects. If empty, defaults to
@@ -1055,11 +1061,11 @@ registerGlobalValue(supybot.protocols.irc, 'umodes',
 
 registerGlobalValue(supybot.protocols.irc, 'vhost',
     registry.String('', _("""Determines what vhost the bot will bind to before
-    connecting a server (IRC, HTTP, …) via IPv4.""")))
+    connecting a server (IRC, HTTP, ...) via IPv4.""")))
 
 registerGlobalValue(supybot.protocols.irc, 'vhostv6',
     registry.String('', _("""Determines what vhost the bot will bind to before
-    connecting a server (IRC, HTTP, …) via IPv6.""")))
+    connecting a server (IRC, HTTP, ...) via IPv6.""")))
 
 registerGlobalValue(supybot.protocols.irc, 'maxHistoryLength',
     registry.Integer(1000, _("""Determines how many old messages the bot will
